@@ -33,8 +33,8 @@
 								'punctuation': /^=|^["']|["']$/
 							}
 						},
-						'keyword': /\w+(?=\s)/,
-						'attr-name': /\w+/
+						'keyword': /\b\w+(?=\s)/,
+						'attr-name': /\b\w+/
 					}),
 					'expression': createBlock('=', grammar, className),
 					'class-feature': createBlock('\\+', grammar, className),
